<!-- 
# IMPORTANT: Please do not create a Pull Request without creating an issue first
-->

## Title

The title of the PR should follow [conventional commits](https://www.conventionalcommits.org/en/v1.0.0/#summary), as all the commits within the PR will be squashed under the title.

feat(location): add Foo to Bar

### Description

A one to two sentence summary of the PR for easy digestion, must be
different and more descriptive than title. Combination of tile and
description should summarize the issue + solution.

Feel free to add any additional information as a bulleted list.

### Related Issue(s)

Remove this line and link your issue here with the `Resolves` keyword
Resolves #1234

### Reviewers

List all reviewers here and briefly describe why they are invited for
review.
By default, the PR author should merge once the reviewers have had a
chance to review.
If you have a different preference or cannot merge after review for some
other constraint, leave a note about it here.

### Acceptance Criteria

What needs to happen functionally for this work to pass review, copy paste from issue.

### Testing

Add how you tested this PR and add a sequence of steps, with images where appropriate, for testing this PR.
